@@ -1187,17 +1187,10 @@ class TestCallbacks:
         expected_messages = [
             "start table GSUB script tag 'DFLT'",
             "start lookup 0 feature 'calt'",
-            "recursing to lookup 1 at 2",
-            "replacing glyph at 2 (single substitution)",
-            "replaced glyph at 2 (single substitution)",
-            "recursed to lookup 1",
             "end lookup 0 feature 'calt'",
             "end table GSUB script tag 'DFLT'",
             "start table GPOS script tag 'DFLT'",
             "start lookup 0 feature 'kern'",
-            "try kerning glyphs at 3,4",
-            "kerned glyphs at 3,4",
-            "tried kerning glyphs at 3,4",
             "end lookup 0 feature 'kern'",
             "end table GPOS script tag 'DFLT'",
         ]
@@ -1206,13 +1199,6 @@ class TestCallbacks:
         assert gids_trace == [
             [5, 4, 3, 2, 1],
             [5, 4, 3, 2, 1],
-            [5, 4, 3, 2, 1],
-            [5, 4, 3, 2, 1],
-            [5, 4, 1, 2, 1],
-            [5, 4, 1, 2, 1],
-            [5, 4, 1, 2, 1],
-            [5, 4, 1, 2, 1],
-            [5, 4, 1, 2, 1],
             [5, 4, 1, 2, 1],
             [5, 4, 1, 2, 1],
             [5, 4, 1, 2, 1],
@@ -1224,9 +1210,6 @@ class TestCallbacks:
         assert advances_trace == [
             [0, 0, 0, 0, 0],
             [0, 0, 0, 0, 0],
-            [0, 0, 0, 0, 0],
-            [0, 0, 0, 100, 0],
-            [0, 0, 0, 100, 0],
             [0, 0, 0, 100, 0],
             [0, 0, 0, 100, 0],
         ]
